@@ -5,7 +5,7 @@
  * @date     Tue Aug 05, 2003 21:50
  * @brief    XMMS GNOME applet callbacks
  *
- * $Id: callbacks.c,v 1.4 2004/06/09 23:40:41 aleix Exp $
+ * $Id: callbacks.c,v 1.5 2004/09/02 22:19:54 aleix Exp $
  *
  * @if copyright
  *
@@ -218,6 +218,39 @@ cb_button_press(GtkWidget *w, GdkEventButton *event, gpointer data)
     return FALSE;
 }
 
+void
+cb_repeat_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb)
+{
+    /* empty (Bonobo UI component listener is used instead) */
+}
+
+void
+cb_shuffle_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb)
+{
+    /* empty (Bonobo UI component listener is used instead) */
+}
+
+void
+cb_toggle_repeat(BonoboUIComponent *uic, const gchar *path,
+                 Bonobo_UIComponent_EventType type, const gchar *state,
+                 gpointer data)
+{
+    XMMSData *xmms = data;
+
+    xmms_repeat(xmms, strcmp(state, "0"));
+}
+
+void
+cb_toggle_shuffle(BonoboUIComponent *uic, const gchar *path,
+                  Bonobo_UIComponent_EventType type, const gchar *state,
+                  gpointer data)
+{
+    XMMSData *xmms = data;
+
+    xmms_shuffle(xmms, strcmp(state, "0"));
+}
+
+
 void
 cb_main_win_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb)
 {
@@ -250,6 +283,14 @@ cb_show_hide_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb)
     xmms_show_hide(xmms);
 }
 
+void
+cb_xmms_pref_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb)
+{
+    XMMSData *xmms = data;
+
+    xmms_preferences(xmms);
+}
+
 void
 cb_about_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb)
 {
@@ -267,7 +308,7 @@ cb_about_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb)
     }
     about = gnome_about_new(
         PACKAGE_NAME, PACKAGE_VERSION, "Copyright (C) 2003, 2004 Aleix Conchillo Flaque\n",
-        _("gXMMS lets you control the X MultiMedia System (XMMS).\n"),
+        _("gxmms lets you control the X MultiMedia System (XMMS).\n"),
         authors, NULL, NULL,
         gdk_pixbuf_new_from_file(GXMMS_DATADIR"/gxmsms.png", 0));
 
