@@ -5,7 +5,7 @@
  * @date     Tue Aug 05, 2003 21:56
  * @brief    XMMS GNOME applet callbacks
  *
- * $Id: callbacks.h,v 1.2 2004/06/09 23:40:43 aleix Exp $
+ * $Id: callbacks.h,v 1.3 2004/09/02 22:19:54 aleix Exp $
  *
  * @if copyright
  *
@@ -64,6 +64,18 @@ gboolean cb_scrollwheel(GtkWidget *w, GdkEventScroll *event, gpointer data);
 
 gboolean cb_button_press(GtkWidget *w, GdkEventButton *event, gpointer data);
 
+void cb_repeat_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb);
+
+void cb_shuffle_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb);
+
+void cb_toggle_repeat(BonoboUIComponent *uic, const gchar *path,
+                      Bonobo_UIComponent_EventType type, const gchar *state,
+                      gpointer data);
+
+void cb_toggle_shuffle(BonoboUIComponent *uic, const gchar *path,
+                       Bonobo_UIComponent_EventType type, const gchar *state,
+                       gpointer data);
+
 void cb_main_win_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb);
 
 void cb_pl_win_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb);
@@ -73,6 +85,9 @@ void cb_eq_win_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb);
 void cb_show_hide_menu(BonoboUIComponent *uic, gpointer data,
                        const gchar *verb);
 
+void cb_xmms_pref_menu(BonoboUIComponent *uic, gpointer data,
+                       const gchar *verb);
+
 void cb_about_menu(BonoboUIComponent *uic, gpointer data, const gchar *verb);
 
 #endif /* CALLBACKS_H_ALEIX0308052156 */
