@@ -5,7 +5,7 @@
  * @date     Tue Aug 05, 2003 21:59
  * @brief    XMMS GNOME applet GUI
  *
- * $Id: interface.c,v 1.2 2004/06/09 23:40:43 aleix Exp $
+ * $Id: interface.c,v 1.3 2004/09/02 22:19:54 aleix Exp $
  *
  * @if copyright
  *
@@ -37,6 +37,7 @@
 #include <string.h>
 
 /* Static functions definition (declaration at end of file) */
+static void init_menu(XMMSData *xmms);
 static void init_stock_icons(XMMSData *xmms);
 static void register_stock_icons(XMMSData *xmms, GtkIconFactory *factory);
 static void reload_images(XMMSButton *b, GtkStyle *style,
@@ -72,17 +73,7 @@ static const gchar *GXMMS_IMAGE_EXT = ".png";
 void
 gui_create(XMMSData *xmms)
 {
-    static const BonoboUIVerb gxmmsMenuVerbs[] = {
-        BONOBO_UI_VERB ("MainWin", cb_main_win_menu),
-        BONOBO_UI_VERB ("PlWin", cb_pl_win_menu),
-        BONOBO_UI_VERB ("EQWin", cb_eq_win_menu),
-        BONOBO_UI_VERB ("ShowHide", cb_show_hide_menu),
-        BONOBO_UI_VERB ("About", cb_about_menu),
-        BONOBO_UI_VERB_END
-    };
-    GtkWidget *applet;
-
-    applet = xmms->applet;
+    GtkWidget *applet = xmms->applet;
 
     init_stock_icons(xmms);
 
@@ -108,14 +99,10 @@ gui_create(XMMSData *xmms)
     xmms->orient = panel_applet_get_orient(PANEL_APPLET(applet));
 
     /* Setup menu */
-    panel_applet_setup_menu_from_file(PANEL_APPLET(applet),
-                                      NULL,
-                                      "GNOME_gxmmsApplet.xml",
-                                      NULL,
-                                      gxmmsMenuVerbs,
-                                      xmms);
+    init_menu(xmms);
 
-    /* We probably have access to the applet but not to our XMMSData */
+    /* Somwhere we'd probably have access to the applet but not to our
+       XMMSData */
     g_object_set_data(G_OBJECT(applet), "xmms", xmms);
 
     g_signal_connect(applet, "destroy", G_CALLBACK (cb_destroy), xmms);
@@ -226,6 +213,7 @@ gui_update(XMMSData *xmms)
     gint total_time;
     gdouble width;
     GtkWidget *progress;
+    BonoboUIComponent *popup;
     gchar info[256] = _("No track");
 
     progress = xmms->track_control.progress;
@@ -254,6 +242,16 @@ gui_update(XMMSData *xmms)
         sprintf(info, "%d. %s (%02d:%02d)", pos + 1, track, minutes, seconds);
     }
     gtk_tooltips_set_tip(xmms->tooltips, xmms->track_control.box, info, NULL);
+
+    /* Update popup checkboxes */
+    popup = panel_applet_get_popup_component(PANEL_APPLET(xmms->applet));
+
+    bonobo_ui_component_set_prop(popup, "/commands/Repeat", "state",
+                                 xmms_remote_is_repeat(xmms->session) ? "1" : "0",
+                                 NULL);
+    bonobo_ui_component_set_prop(popup, "/commands/Shuffle", "state",
+                                 xmms_remote_is_shuffle(xmms->session) ? "1" : "0",
+                                 NULL);
 }
 
 void
@@ -288,6 +286,47 @@ gui_show_error(XMMSData *xmms, const gchar *msg)
 
 /* Static functions declaration */
 
+static void
+init_menu(XMMSData *xmms)
+{
+    static const BonoboUIVerb gxmms_menu_verbs[] = {
+        BONOBO_UI_UNSAFE_VERB("Repeat",   cb_repeat_menu),
+        BONOBO_UI_UNSAFE_VERB("Shuffle",  cb_shuffle_menu),
+        BONOBO_UI_UNSAFE_VERB("MainWin",  cb_main_win_menu),
+        BONOBO_UI_UNSAFE_VERB("PlWin",    cb_pl_win_menu),
+        BONOBO_UI_UNSAFE_VERB("EQWin",    cb_eq_win_menu),
+        BONOBO_UI_UNSAFE_VERB("ShowHide", cb_show_hide_menu),
+        BONOBO_UI_UNSAFE_VERB("XMMSPref", cb_xmms_pref_menu),
+        BONOBO_UI_UNSAFE_VERB("About",    cb_about_menu),
+        BONOBO_UI_VERB_END
+    };
+    BonoboUIComponent *popup;
+    GtkWidget *applet = xmms->applet;
+
+    panel_applet_setup_menu_from_file(PANEL_APPLET(applet),
+                                      NULL,
+                                      "GNOME_gxmmsApplet.xml",
+                                      NULL,
+                                      gxmms_menu_verbs,
+                                      xmms);
+
+    popup = panel_applet_get_popup_component(PANEL_APPLET(applet));
+
+    bonobo_ui_component_add_listener(popup, "Repeat",
+                                     (BonoboUIListenerFn) cb_toggle_repeat,
+                                     xmms);
+    bonobo_ui_component_add_listener(popup, "Shuffle",
+                                     (BonoboUIListenerFn) cb_toggle_shuffle,
+                                     xmms);
+
+    bonobo_ui_component_set_prop(popup, "/commands/Repeat", "state",
+                                 xmms_remote_is_repeat(xmms->session) ? "1" : "0",
+                                 NULL);
+    bonobo_ui_component_set_prop(popup, "/commands/Shuffle", "state",
+                                 xmms_remote_is_shuffle(xmms->session) ? "1" : "0",
+                                 NULL);
+}
+
 static void
 init_stock_icons(XMMSData *xmms)
 {
